
% File name: min_power.m
% Determines minimum signal power required to give S/N ratio of one
% for a PIN detector
clear all
h_Planck = 6.6261d-34;      % Planck's constant (J s)
c_light=299.80d6;           % speed of light (m/s)
k_B= 1.3807d-23;            % Boltzmann constant (J/K)
e=1.602d-19;                % electron's charge (C)
%
C_j = 1d-12;                % junction capacitance (1pF)
eta = 1;                    % quantum efficiency
lambda = 0.85d-6;           % wavelength (0.85 microns)
B = 1d6:1d5:1d10;           % range of detector bandwidth
%
for T_eff = [500 1000 1500]
    P_min=(2*h_Planck*c_light/(eta*e*lambda))*sqrt(2*pi*k_B*T_eff*C_j)*B;
    loglog(B,P_min,'LineWidth',1.5)
    hold on
end
%
xlabel('Detector bandwidth (Hz)','FontSize',14); 
ylabel('Minimum signal power (W)','FontSize',14); 
text(1d9, 4d-7, '500K','Fontsize',14)
text(5d7, 4d-7, '1500K','Fontsize',14)
set(gca,'FontSize',14);      % size of tick marks on both axis
grid on
pause
close all
