% File name: fdtd_2D.m
% Program for finite-difference time-domain method in 2D
% Propagation of Gaussian pulse
clear all;
N_x = 60;               % number of steps in x-direction
N_y = 60;               % number of steps in y-direction
N_steps = 60;           % number of time steps
%        
N_x_middle = N_x/2.0;   % middle point; location of pulse
N_y_middle = N_y/2.0;   %
%
delta_x = 0.01;         % cell size
delta_t = delta_x/6e8;  % time step
epsilon = 8.8e-12;
%
% Initialization
E_z = zeros(N_x,N_y);   % Initialize field to zero at all points
H_x = zeros(N_x,N_y);
H_y = zeros(N_x,N_y);
%
t_zero = 20.0;          % center of incident pulse
width = 6.0;            % width of the incident pulse
time = 0.0;
%
for istep = 1:N_steps   % main loop
    time = time + 1;
% calculate E_z field
    for i = 2:N_x  
        for j = 2:N_y
            E_z(i,j)=E_z(i,j)+0.5*(H_y(i,j)-H_y(i-1,j)-H_x(i,j)+H_x(i,j-1));
        end
    end      
% Gaussian pulse in the middle  
pulse = exp(-0.5*((t_zero - time)/width)^2); % Gaussian pulse
E_z(N_x_middle,N_y_middle) = pulse;
% 
% Calculate H_x field
    for i = 1:(N_x-1)
        for j = 1:(N_y-1)
        H_x(i,j) = H_x(i,j) - 0.5*(E_z(i,j+1) - E_z(i,j));
        end
    end
%
% Calculate H_y field
    for i = 1:(N_x-1)
        for j = 1:(N_y-1)
        H_y(i,j) = H_y(i,j) + 0.5*(E_z(i+1,j) - E_z(i,j));
        end
    end
end
%----------- Plotting------------------------------
[x,y] = meshgrid(0:1:N_x-1,0:1:N_y-1);
mesh(x,y,E_z);
xlabel('\bfx','FontSize',14); 
ylabel('\bfy','FontSize',14); 
zlabel('\bfE_z','FontSize',14);
set(gca,'FontSize',14);            % size of tick marks on both axis
axis([0 60 0 60 0 1])
text(50,40,0.5, 'time = 60', 'Fontsize', 14)
pause
close all
