% File name: fdtd_free.m
% Plots E and H components of Gaussian pulse in a free space 
% after some number of time steps using FDTD method
% No animation
clear all;
N_x = 200;                 % number of x-cells
N_time = 100;              % number of time steps
time = 0.0;
E_y = zeros(N_x,1);        % Initialize fields to zero at all points
H_z = zeros(N_x,1);
t_zero = 40.0;             % center of incident pulse
width = 12;                % width of the incident pulse
tic;    % start timer
for istep = 1:N_time       % time loop
    time = time + 1;
    pulse = exp(-0.5*((t_zero - time)/width)^2); % Gaussian pulse
    for i = 2:(N_x)
        E_y(120) = pulse;   % location of initial pulse
        E_y(i) = E_y(i) - 0.5*(H_z(i) - H_z(i-1));
    end
    %
    for i = 1:(N_x -1)
        H_z(i) = H_z(i) - 0.5*(E_y(i+1) - E_y(i));
    end
end
toc     % measure elapsed time since last call to tic
subplot(2,1,1); plot(E_y)
ylabel('E_y'); xlabel('FDTD cells')
axis([0 200 -1 1])
subplot(2,1,2); plot(H_z)
ylabel('H_z'); xlabel('FDTD cells')
axis([0 200 -1 1])
pause
close all
