
% File name: bpm_taper.m
% Illustrates propagation of Gaussian pulse in a free space
% using BPM with transparent boundary conditions
clear all
L_x=10.0;                           % transversal dimension (along x-axis)
w_0=1.0;                            % width of input Gaussian pulse
lambda = 1.6;                       % wavelength
n=1.0;                              % refractive index of the medium
k_0=2*pi/lambda;                    % wavenumber
N_x=128;                            % number of points on x axis
Delta_x=L_x/(N_x-1);                % x axis spacing
h=5*Delta_x;                        % propagation step
N_z=100;                            % number of propagation steps
plotting_struct=zeros(N_x,N_z);     % storage for plotting
plotting_field=zeros(N_x,N_z);      % storage for plotting
x=linspace(-0.5*L_x,0.5*L_x,N_x);   % coordinates along x-axis
x = x';
E=exp(-(x/w_0).^2);                 % initial Gaussian field
n_eff = 1.15;
%
z = 0;
z_plot = zeros(N_z);
for r=1:N_z                         % BPM stepping
    z = z + h; 
    z_plot(r) = z + h;
    index = taper_struct(z,x,N_x,N_z);
    plotting_struct(:,r)=taper_struct(z,x,N_x,N_z);  
    plotting_field(:,r)=abs(E).^2;   
    E=step(Delta_x,k_0,h,index,n_eff,E); % Propagates pulse over one step
end;
%
for k = 1:N_z/20:N_z                % choosing 2D plots every 10-th  step
    plot(plotting_struct(:,k),'LineWidth',1.1)
    plot(plotting_field(:,k),'LineWidth',1.5)
    set(gca,'FontSize',14);         % size of tick marks on both axis
    hold on
end
pause
close all
%
for k = 1:N_z/10:N_z                % choosing 3D plots every 10-th step
    y = z_plot(k)*ones(size(x));    % spread out along y-axis
    plot3(x,y,plotting_struct(:,k),'LineWidth',1.1)
    plot3(x,y,plotting_field(:,k),'LineWidth',1.5)
    hold on
end
grid on
xlabel('x','FontSize',14)  
ylabel('z','FontSize',14)           % along propagation direction
set(gca,'FontSize',14);             % size of tick marks on both axis
pause
close all
