% File name: bpm_wg.m
% Driver function which propagates Gaussian pulse 
% in a strip waveguide using BPM with transparent boundary conditions
clear all
x_0 = 1;                            % center of Gaussian pulse
L_x=10.0;                           % transversal dimension (along x-axis)
w_0=1.0;                            % width of input Gaussian pulse
lambda = 1.6;                       % wavelength
k_0=2*pi/lambda;                    % wavenumber
N_x=128;                            % points on x axis
Delta_x=L_x/(N_x-1);                % x axis spacing
h=5*Delta_x;                        % propagation step
N_z=100;                            % number of propagation steps
plot_index=zeros(N_x,N_z);          % storage for plotting ref. index 
plot_field=zeros(N_x,N_z);          % storage for plotting field
x=linspace(-0.5*L_x,0.5*L_x,N_x);   % coordinates along x-axis
x = x';
E=exp(-((x - x_0)/w_0).^2);         % initial Gaussian field
ref_index = wg_struct(x);           % structure is uniform along z-axis
n_eff = 1.40;                       % assumed value of prop. constant
%
z = 0;
z_plot = zeros(N_z);
for r=1:N_z
    z = z + h; 
    z_plot(r) = z + h;  
    plot_index(:,r)=wg_struct(x);
    plot_field(:,r)=abs(E).^2;
    E = step(Delta_x,k_0,h,ref_index,n_eff,E);
end;
%
for k = 1:N_z/10:N_z                % choosing 2D plots every 10-th  step
    plot(x,plot_index(:,k),'LineWidth',1.2)
    plot(x,plot_field(:,k),'LineWidth',1.5)
    hold on
end
pause
close all
%
for k = 1:N_z/10:N_z                % choosing 3D plots every 10-th step
    y = z_plot(k)*ones(size(x));    % spread out along y-axis
    plot3(x,y,plot_index(:,k),'LineWidth',1.2)
    plot3(x,y,plot_field(:,k),'LineWidth',1.5)
    hold on
end
grid on
xlabel('x')
ylabel('z')                    % along propagation direction
pause
close all
