
% File name: link.m
% Optical link simulations
% Follow code on p.133 of S. Geckeler (1983) paper
% No model of a transmitter
% No noise
%
clear all
%----------- Pulse produced by transmitter ----------------------
R_0 = 50d5;               % Bit rate of binary digital signal, 50 Mbit/s
P_0 = 5d-4;               % Max power of optical pulse, 0.5 mW
T_0 = 0.7;                % Normalized pulse duration = tau_0/T
%------------- Fiber parameters -------------------------
L_1 = 15;                 % Fiber length, 15 km
A_L = 3.0;                % Attenuation coefficient, 3 dB/km
D_1 = 10^(-A_L*L_1/10);   % Power ratio 
P_1 = P_0*T_0*D_1/2;      % Mean optical power at the end of fiber
B_L = 5d8;                % Bandwidth-length product, 500 MHz km
L_C = 10;                 % Coupling length of a multimode fiber, 10 km
B_1 = B_L/L_1 + B_L/(3*L_C);        % Fiber bandwidth
T_1 = R_0/(2*B_1);              
%-------------- Receiver parameters -------------------------
T_2 = 0.7;    
%============== System evaluation =======================================
% Output signal spectrum
D_F = pi/(20*T_2);
N = 32;
f = zeros(1,N);
f_A = zeros(1,N);
f_B = zeros(1,N);
f_C = zeros(1,N);
H_F = zeros(1,N);
H_F(1) = 1.0;
for j = 1:N
    f(j) = j*D_F;
    f_A(j) = sin(f(j)*T_0)/(f(j)*T_0);     % transmitter
    f_B(j) = exp(-f(j)^2*T_1*T_1/pi);      % fiber
    f_C(j) = (1/2)*(1 + cos(f(j)*T_2));    % receiver
    H_F(j) = f_A(j)*f_B(j)*f_C(j);
end
%
plot(f,f_A,'.',f,H_F,'LineWidth',1.5)      % Plot signal after propagation
xlabel('Frequency (a.u.)','FontSize',14);
set(gca,'FontSize',14);            % size of tick marks on both axis
pause
s = ifft(H_F);
s = s/max(s);
ff = linspace(0,2/3,N);
%
plot(fftshift(abs(s)),'LineWidth',1.5);
xlabel('time','FontSize',14);
ylabel('time output function','FontSize',14);
set(gca,'FontSize',14);            % size of tick marks on both axis
grid
pause
close all
