
% File name: rectangular.m
% Analysis of rectangular pulse after filtering
%
clear all
hwidth = 10;                         % half-width of a pulse
time_step = 0.001;                   % time step
range = 40;
t = -range:time_step:range;          % time range
%------ Creation of rectangular pulse -------
y = (5/2)*(sign(t+hwidth)-sign(t-hwidth));
plot(t,y,'LineWidth',1.5);
xlabel('time (a.u','FontSize',14); 
ylabel('Pulse amplitude','FontSize',14);
set(gca,'FontSize',14);              % size of tick marks on both axis
axis([-range range 0 6]);
pause
% %----- Fourier transform of a rectangular pulse -------
y_shift = fftshift(fft(y));
N=length(y_shift);          
n=-(N-1)/2:(N-1)/2;   
%------ Definitions of different filters ------------------
filter = (1/2)*(sign(n+100)-sign(n-100));
%filter = exp(-pi*n*0.0001);
%filter = 0.1*cos(pi*n*0.005).^2; 
%filter = (1 + cos(0.05*n))/2;
plot(n,filter,'LineWidth',1.5);
axis([-3*range 3*range 0 1.5]);
xlabel('Frequency (a.u.)','FontSize',14);  
ylabel('Amplitude','FontSize',14);
set(gca,'FontSize',14);              % size of tick marks on both axis
pause
%-------- Regeneration of signal using filtered output ----------
y_reg=filter.*y_shift;               % Filter original frequency spectrum
y_reg_inv=ifft(y_reg);               % Inverse Fourier transform
plot (t,abs(y_reg_inv),'LineWidth',1.3);
axis([-range range 0 6]);
xlabel('Time(a.u.)','FontSize',14);  
ylabel('amplitude','FontSize',14);
set(gca,'FontSize',14);              % size of tick marks on both axis
pause
close all
