
% File name: ssftm_full.m
% Split-step Fourier transfer method for the analysis of solitons
% Contains the following initial pulses
% N=1 soliton
% N=3 solitons
% Chirp N=1 soliton
% Two interacting solitons
% For the analysis of the appropriate case it should be uncommented
%
clear all
tic;
%===== Material parameters ===================
%alpha=0.01;                      % Fiber loss (dB/km)
alpha = 0.0;
alpha=alpha/(4.343);            % Fiber loss (1/km)
gamma = 1.3;                    % Fiber nonlinearity [1/W/km]
beta_2=15d-24;                  % 2nd order disp. (s^2/km)
%====== Time parameters ===========
T =- 512e-12:1e-12: 511e-12;
delta_t=1e-12;
%======= Input pulse and its parameters ========
T_0 = 100d-12;                  % Initial pulse width (s)
P_0 = 0.15d-3;                  % Input power (Watts)
A_0 = sqrt(P_0);              
L_D =((T_0^2)/(abs(beta_2)));   % Dispersion length in [km] 
L_NL = (1/(gamma*P_0));
h = 2d0;                        % step size [km]
z_plot = (0:h:((pi/2)*L_D));    % z-values to plot [in km]   
n = 1;                          % controls stepping
z_0 = (pi/2)*L_D;               % Soliton period [km]
N = 3;                          % Soliton number
%A = N^2*A_0*sech(T/T_0);        % N=3 soliton
%A = A_0*sech(T/T_0);           % N=1 soliton
C = 1.6;                        % chirp parameter
%A = A_0*sech(T/T_0).*exp((-1i*C/2).*(T/T_0).^2);  % N=1 soliton with chirp
A = A_0*sech(T/T_0-1.6)+A_0*sech(T/T_0+1.6);        % interacting solitons
%   
L = max(size(A));     
Delta_omega=1/L/delta_t*2*pi;
omega = (-L/2:1:L/2-1)*Delta_omega;
A_f = fftshift(fft(A));         % Pulse in frequency domain
for jj=h:h:z_0
    A_f = A_f.*exp(-alpha*(h/2)-1i*beta_2/2*omega.^2*(h/2));
    A_t =ifft(A_f);             % Pulse in time domain
    A_t = A_t.*exp(1i*gamma*((abs(A_t)).^2)*(h));
    A_f = fft(A_t);
    A_f = A_f.*exp(-alpha*(h/2)-1i*beta_2/2*omega.^2*(h/2));
    A_t = ifft(A_f);
    plotting(:,n) = abs(A_t);
    n = n+1;
end
toc;
cputime=toc;
%
z_plot = h:h:z_0;               % creates distance for plotting
length(z_plot)
for k = 1:80:length(z_plot)     % Choosing 3D plots every 10-th step
    y = z_plot(k)*ones(size(T));% Spread out along y-axis
    plot3(T*1d12,y,plotting(:,k),'LineWidth',1.5)
    hold on 
end
xlabel('time (ps)','FontSize',14); 
ylabel('distance (km)','FontSize',14);
set(gca,'FontSize',14);         % size of tick marks on both axis
grid on
pause
close all
