
% File name: solar_Si.m
% Simulates ideal solar cell based on Si
clear all
eta = 1.5;
I_ph = 0.02;                        % illumination current, in mA
T = 330;
V_init = 0;
V_final = 1.0;
V_step = 0.01;
V=0;
hold on
for R_s = [0.01 20 50]              % series resistance, in ohms
curr_total = fzero(@(curr) current_V(curr,V,T,eta,I_ph,R_s),0.2);
for V = V_init:V_step:V_final
    curr = fzero(@(curr) current_V(curr,V,T,eta,I_ph,R_s),0.2); 
    curr_total = [curr_total, curr];  
end
V_plot = V_init:V_step:V_final;     % creation voltage values for plot
V_plot = [0, V_plot];
plot(V_plot, curr_total,'LineWidth',1.5)
set(gca,'FontSize',14);             % size of tick marks on both axis
axis([0 V_final*0.8 0 I_ph*1.2]);
ylabel('Current (mA)','Fontsize',14)  
xlabel('Voltage (V)','Fontsize',14)
text(0.65, 0.01, 'R_s = 0 \Omega','Fontsize',14)
text(0.45, 0.01, 'R_s = 20 \Omega','Fontsize',14)
text(0.2, 0.01, 'R_s = 50 \Omega','Fontsize',14)
end
pause
close all
