
% File name: ChenFig3.m
% Matlab code to plot Fig.3 of Chen et al
% using equivalent circuits approach
% Plot Fig3. of Chen et al, JAP,v.100, 024915 (2006)
clear all
% Fundamental constants
epsilon_zero=8.8542d-12;    % epsilon zero (F/m)  
mu_zero = 4*pi*10^-7;       % mu zero (H/m)
%
% Geometrical dimensions, see Fig.1 of Chen
r = 2.0;                    % internal radius = 2 mmm
a = 5.0;                    % distance between elements = 5 mm
l_vert = 1.0;               % vertical separation = 1 mm
L_c = 1.0;                  % Dimension of capacitor = 1 mm
t = 0.8;                    % Dimension of capacitor = 0.8 mm
d_c = 0.2;                  % Dimension of capacitor = 0.2 mm
eps_r = 4.0;                % permittivity of the gap
sigma = 10^-6;              % resistance per unit length
%
% Intermediate parameters
F = pi*r^2/(a^2);           % fractional volume (dimensionless)
C_g = (epsilon_zero*eps_r*L_c*t/d_c)*10^-3; % gap capacitance unit (F)
L = (mu_zero*pi*r^2/l_vert)*10^-3;          % Eg.(2) unit (H)
% pause
R = 2*pi*r*sigma;                       % resistance of the ring
C = C_g/2.0;                            % total capacitance in the loop
%
% Determination of frequency range
N_max = 200;                            % number of points for plot
                                        % in the interval [0,10] GHz
freq_GHz = linspace(0,10,N_max);        % creation of frequency arguments
freq_Hz = freq_GHz*10^9;
omega_Hz = 2.0*pi*freq_Hz;
%
tt = 1./(omega_Hz.^2*L*C);
ttt = R./(omega_Hz.*L);
temp = 1./tt + 1i*ttt;
%
% effective permeability without coupling M, Eq.(9) of Chen
extra = F./(1. + F - tt + 1i*ttt);
%
mu_eff = 1. - F./(1. + F - tt + 1i*ttt);
result_re = real(mu_eff);
result_im = imag(mu_eff);
%
% plot(freq_GHz,result_im);
% pause
plot(freq_GHz,result_re,freq_GHz,result_im,'.','LineWidth',1.5);
axis([0 10 -20 20])
xlabel('Frequency (GHz)','FontSize',14);
ylabel('Effective permeability','FontSize',14);
set(gca,'FontSize',14);            % size of tick marks on both axis
grid
pause
close all
