
% File name: group_velocity.m
% Illustrative plot of group velocity by superposition
% of two plane waves
clear all
N_max = 300;                        % number of points for plot
t = linspace(0,300d-15,N_max);      % creation of theta arguments
%
c = 3d14;                           % velocity of light in microns/s
n = 3.4;                            % refractive index
v_p = c/n;                          % phase velocity
lambda = 1.0;                       % microns
frequency = v_p/lambda;
z = 0.6;                            % distance in microns 
omega = 2*pi*frequency;
k = 2*pi/lambda;
Delta_omega = omega/15.0;
Delta_k = k/15.0;
%
omega_1 = omega + Delta_omega;
omega_2 = omega - Delta_omega;
k_1 = k + Delta_k;
k_2 = k - Delta_k;
A = 2*cos(k*z - omega*t).*cos(Delta_k*z - Delta_omega*t); 
plot(t,A,'LineWidth',1.3)
xlabel('Time','FontSize',14)
ylabel('Amplitude','FontSize',14) 
set(gca,'FontSize',14);             % size of tick marks on both axis
pause
close all
