
% reflections_TE_TM.m
% Plot of reflections based on Fresnel equations
% TE and TM reflections
% cases of external reflection
clear all
n = 1.50;                           % relative refractive index
N_max = 11;                         % number of points for plot
t = linspace(0,1,N_max);            % creation of theta arguments
theta = (pi/2)*t;                   % angles in radians
% Plot reflection coefficients
num_TE = cos(theta) - sqrt(n^2-(sin(theta)).^2 );
den_TE = cos(theta) + sqrt(n^2-(sin(theta)).^2 );
r_TE = num_TE./den_TE;              % Plot for TE mode
num_TM = n^2*cos(theta) - sqrt(n^2-(sin(theta)).^2 );
den_TM = n^2*cos(theta) + sqrt(n^2-(sin(theta)).^2 );
r_TM = num_TM./den_TM;              % Plot for TM mode
%
angle_degrees = (theta./pi)*180;
x_line = [0 max(angle_degrees)];    % needed to draw horizontal line
y_line = [0 0];                     % passing through zero
plot(angle_degrees,r_TE,angle_degrees,r_TM, x_line, y_line, '-',...
    'LineWidth',1.5)
xlabel('Angle of incidence','FontSize',14)
set(gca,'FontSize',14);             % size of tick marks on both axis
text(60, -0.6, 'r_{TE}','Fontsize',14)
text(60, -0.2, 'r_{TM}','Fontsize',14)
text(55, 0.1, '\theta_{Brewster}','Fontsize',14)
pause
close all
