% File name: lossless.m
% Contains data for lossless waveguide
% Reference:
% J. Chilwell and I. Hodgkinson,
% "Thin-films field-transfer matrix theory of planar multilayer
% waveguides and reflection from prism-loaded waveguide",
% J. Opt. Soc. Amer.A, vol.1, pp. 742-753 (1984).
% Fig.3
% Global variables to be transferred to function f_TE.m
%
global n_c            % ref. index cladding
global n_layer        % ref. index of internal layers
global n_s            % ref. index substrate
global d_c            % thickness of cladding (microns)
global d_layer        % thicknesses of internal layers (microns)
global d_s            % thickness of substrate (microns)
global k_0            % wavenumber
global NumberMesh     % number of mesh points in each layer 
                      % (including substrate and cladding)
n_c        = 1.0;
n_layer    = [1.66 1.60 1.53 1.66];
n_s        = 1.5;
d_c        = 0.5;
d_layer    = [0.5 0.5 0.5 0.5];
d_s        = 1.0;
NumberMesh = [10 10 10 10 10 10];   
lambda     = 0.6328;  % wavelength in microns
k_0        = 2*pi/lambda;
