% File name: disp_mat.m
% Plots D_mat
% Material dispersion is determined using Sellmeier equation
% describing refractive index for pure and doped silica
% Data from Kasap2001, p.45 for SiO_2 - GeO_2
clear all
c_light = 3d5;                    % velocity of light, km/s
disp_min = -20; disp_max =20;
N_max = 101;                      % number of points for plot
lambda_min = 1.200; lambda_max = 1.600;  % in microns
% creation of lambda arguments between 1.2 and 1.6 microns
lambda = linspace(lambda_min,lambda_max,N_max);                                   
G_1 = 0.711040; G_2 = 0.451885; G_3 = 0.704048;
lambda_1 = 0.0642700; lambda_2 = 0.129408; lambda_3 = 9.425478;
%
term1 = (G_1*lambda.^2)./(lambda.^2 - lambda_1^2);
term2 = (G_2*lambda.^2)./(lambda.^2 - lambda_2^2);
term3 = (G_3*lambda.^2)./(lambda.^2 - lambda_3^2);
%
ref_index_sq = 1.0 + term1 + term2 + term3;
ref_index = sqrt(ref_index_sq);
%
%---------- Determination of material dispersion D_mat -------------
ttt1 = ref_index;
dy1_lam = diff(ttt1)./diff(lambda);  % first derivative
lambda1 = lambda(1:length(lambda)-1);
ttt2 = dy1_lam;
dy2_lam = diff(ttt2)./diff(lambda1);
lambda2 = lambda1(1:length(lambda1)-1);
D_mat = (-lambda2.*dy2_lam/c_light)*1d9;
plot(lambda2,D_mat,'LineWidth',1.5);
xlabel('wavelength (\mum)','FontSize',14);
ylabel('Material dispersion (ps/km nm)','FontSize',14);
set(gca,'FontSize',14);            % size of tick marks on both axis
axis([lambda_min, lambda_max, disp_min, disp_max])
grid on
pause
close all
