% File name: sellmeier.m
% Plot of refractive index based on Sellmeier equation
% for Si O_2
clear all
N_max = 101;                        % number of points for plot
lambda = linspace(0.5,1.8,N_max);   % creation of lambda arguments
                                    % between 0.5 and 1.8 microns
%
% Data for SiO_2
G_1 = 0.696749; G_2 = 0.408218; G_3 = 0.890815;
lambda_1=0.0690606; lambda_2=0.115662; lambda_3=9.900559; % in microns
%
term1 = (G_1*lambda.^2)./(lambda.^2 - lambda_1^2);
term2 = (G_2*lambda.^2)./(lambda.^2 - lambda_2^2);
term3 = (G_3*lambda.^2)./(lambda.^2 - lambda_3^2);
ref_index_sq = 1.0 + term1 + term2 + term3;
ref_index = sqrt(ref_index_sq);
%
h = plot(lambda,ref_index,'LineWidth',1.5);
% Redefine figure properties
xlabel('wavelength (\mum)','FontSize',14);
ylabel('refractive index','FontSize',14);
set(gca,'FontSize',14);             % size of tick marks on both axis
pause
close all