
% File name: FT_rp.m 
% Plots symmetric rectangular pulse of duration tau and its
% Fourier transform 
clear all
N_max = 1000;                        % number of points for plot
% Pulse characteristics
tau = 10.0;                          % 1/2 pulse width
A = 0.5;                             % pulse height 
% Plotting Fourier transform of rectangular pulse using analytical formula
omega = linspace(-20/tau, 20/tau, N_max);  % creation of frequency argument
S = 2*A*sin(tau.*omega)./omega;
h = plot(omega,S);
set(h,'LineWidth',1.5);              % thickness of plotting lines 
grid
xlabel('frequency (a.u.)','FontSize',14);
ylabel('Fourier transform (S) (a.u.)','FontSize',14);
set(gca,'FontSize',14);              % size of tick marks on both axis
text(0.65, 0, 'A','Fontsize',13);
text(1, 0, 'B','Fontsize',13);
pause
close all
%---- Plotting rectangular pulse -----------------------------------------
dt = 1/N_max;
t = -6*tau:dt:6*tau;                 % Creation of points for pulse plotting
s = A*(sign(t+tau)-sign(t-tau));
h = plot(t,s);
set(h,'LineWidth',1.5);              % thickness of plotting lines 
axis([-2*tau 2*tau 0 2]);
xlabel('time (a.u.)','FontSize',14); ylabel('s_r (a.u.)','FontSize',14);
set(gca,'FontSize',14);              % size of tick marks on both axis
pause
close all
%----- Plotting its Fourier transform using Matlab functions ---------- 
y = fft(s);        % discrete Fourier transform
SM = fftshift(y);  % shift zero-frequency component to center of spectrum
N = length(SM);
k = -(N-1)/2:(N-1)/2;
f = abs(SM);
h = plot(k,f);
set(h,'LineWidth',1.5);              % thickness of plotting lines 
axis([-4*tau 4*tau -5000 30000]); 
ylabel('Abs FT of rectangular pulse (a.u)','FontSize',14);
grid
set(gca,'FontSize',14);              % size of tick marks on both axis
pause
close all
