% File name: bits_gen.m
%-----------------------------------------------------------------
% Purpose:
% Generates 8-bits long pattern
% generates single bit which is then repeated 8 times
% Source
% R.Sabella and P.Lugli
% "High Speed Optical Communications"
% Kluwer Academic Publishers 1999
% p.32
%*********************************
%
clear all
bits = [0 1 0 0 1 1 0 1];          % Definition of logical pattern
%
T_period = 1d-9;   % pulse period [s]
I_bias = 2;   % mA
I_m = 3;       % mA
tau_r = 0.2*T_period;   % rise time
%
% Generation of current pattern corresponding to bit pattern
I_p = 0;
N_div = 50;   % number of divisions within each bit interval
t = linspace(0, T_period, N_div);   % the same time interval is 
                                    % generated for each bit
%******** first bit *************************************
   if bits(1)==0,     I_p_1 = I_bias + 0*t;
   elseif bits(1)==1, I_p_1 = I_bias + I_m + 0*t;
   end
%------------------------------------------
% Generates single, arbitrary bit
%t = linspace(0, T_period, N_div);
temp_I = I_p_1;
%
number_of_bits = length(bits);
%
for k = 2:number_of_bits
    if bits(k)==1 && bits(k-1)==0
            I_p = I_bias + I_m*(1 - exp(-2.2*t./tau_r));
    elseif bits(k)==0 && bits(k-1)==1
                             I_p = I_bias + I_m*exp(-2.2*t./tau_r);
    elseif bits(k)==0 && bits(k-1)==0
                             I_p = I_bias + 0*t;
    else bits(k)==1 && bits(k-1)==1
                             I_p = I_bias + I_m + 0*t;
    end
    I_p = [temp_I,I_p];
    temp_I = I_p;
end
temp_t = t;
for k = 2:number_of_bits
    t = linspace(0, T_period, N_div);
    t = [temp_t,(k-1)*T_period+t];
    temp_t = t;
end
%
x_min = 0;
x_max = max(t);
y_min = I_bias;
y_max = I_bias + 1.2*I_m;
%
h = plot(t,I_p);
grid on
set(h,'LineWidth',1.5);                 % thickness of plotting lines 
xlabel('time [s]','FontSize',14);       % size of x label
ylabel('Current [mA]','FontSize',14);   % size of y label
set(gca,'FontSize',14);                 % size of tick marks on both axis
axis([x_min x_max y_min y_max])
pause
close all
