
% File name: pdisp.m
% Propagation of Gaussian pulse in the presence of dispersion
% using Fourier transform
clear all;
% Creation of input pulse
T_0 = 1.0;                       % pulse width
T_s = 0.08;                      % sampling period
t = -4:T_s:4-T_s;                % creation of time interval
p = gauss_m(t,T_0);
P=fftshift(fft(p));              % Fourier transform of the original pulse
Fs=1/64;                         % sampling frequency
N=length(t);                     % length of time interval
f = -N/2*Fs:Fs:N/2*Fs-Fs;        % frequency range
omega = 2*pi*f; 
% Parameters of optical fiber
alpha = 0.0;                     % losses
%beta_2 = 60.0;                  % coefficient beta_2 [ps^2/km]
beta_2 = 0.0;                    % coefficient beta_2 [ps^2/km]
beta_3 = 0.01;                   % coefficient beta_3 [ps^3/km]
% Transfer function of optical fiber
distance = 4000;
H=exp((alpha/2+1i/2*beta_2*omega.^2+1i/6*beta_3*omega.^3)*distance); 
%
P_prop = P.*H;                   % Fourier transform of final pulse
p_prop = ifft(fftshift(P_prop)); % time dependence of final pulse 
p_plot = abs(p_prop).^2;
%
h = plot(t, p, '.', t, p_plot);
set(h,'LineWidth',1.5);                   % thickness of plotting lines 
xlabel('time','FontSize',14);             % size of x label
ylabel('Arbitrary units','FontSize',14);  % size of y label
set(gca,'FontSize',14);                   % size of tick marks on both axis
legend('original pulse', 'transmited pulse')
pause
close all
