% File name: ptrain.m
% Generates train of pulses
% Allows for overlap of pulses
clear all
bits = [0 1 0 1 1 0];                   % definition of logical pattern
T = 1d-9;                               % pulse period [s]               
num_pulses = length(bits);              % number of pulses
N = 1000;                               % number of time points
width = 0.3*T;                          % width of pulse
time=linspace(0,num_pulses*T,N);
signal = zeros(1,N);
pulses = zeros(num_pulses,N);
%
t_0= T/2;                     %position of peak of first impulse in signal
for i=1:num_pulses
    if (bits(i)==1)
        pulses(i,:)= fgauss(time,width,t_0);
        signal = signal + fgauss(time,width,t_0);
    end
    t_0 = t_0 + T;
end
%
subplot (2,1,1); h = plot(time,pulses);
set(h,'LineWidth',1.5);                 % thickness of plotting lines 
xlabel('time','FontSize',14);           % size of x label
title('Individual pulses','FontSize',14)
set(gca,'FontSize',14);                 % size of tick marks on both axis
subplot (2,1,2); h = plot(time,signal);
set(h,'LineWidth',1.5);                 % thickness of plotting lines 
xlabel('time','FontSize',14);           % size of x label
set(gca,'FontSize',14);                 % size of tick marks on both axis
title('Total signal','FontSize',14)
pause
close all
