
% File name: pulse_evol.m
% Describes evolution of pulse width as a function of normalized
% distance for chirped and unchirped pulses
%
clear all
% Data
beta_2 = -20;                       % [-20ps^2/km] at 1.55 microns
T_0 = 200;                          % [ps] = 0.2 ns, bit rate 10Gb/s
L_D = (T_0^2)/abs(beta_2);
N_max = 401;                        % number of points for plot
x = linspace(0,1.5,N_max);          % normalized distance; x = z/L_D
%
hold on
for C = [-1 0 1 2]                  % chirped coefficient
    T = sqrt((1+sign(beta_2)*C*x).^2 + (x).^2);  
    h = plot(x,T);
    set(h,'LineWidth',1.5);         % thickness of plotting lines 
end
% Redefine figure properties
ylabel('T_1/T_0','FontSize',14)  
xlabel('z/L_D','FontSize',14)
text(0.35, 1.65, 'C = -1','Fontsize',14)
text(0.35, 1.2, 'C = 0','Fontsize',14)
text(0.35, 0.8, 'C = 1','Fontsize',14)
text(0.35, 0.55, 'C = 2','Fontsize',14)
set(gca,'FontSize',14);             % size of tick marks on both axis
pause
close all
