% File name: sslg.m
% Calculates and plots the evolution of a Gaussian pulse in optical fiber 
% using Fast Fourier Transform split-step method with linear terms only
clear all
% Input parameters
N= 32;                              % number of points along time axis
T_domain = 100;                     % total time domain kept [in ps]
beta_2 = 2;                         % dispersion coefficient [in ps/nm-km]
beta_3 = 1.01;
%
Delta_t = T_domain/N;               % node spacing in time
Delta_om = 2*pi/T_domain;           % node spacing in radial frequency
t = Delta_t*(-N/2:1:(N/2)-1);       % array of time points
omega = Delta_om*(-N/2:1:(N/2)-1);  % array of radial frequency points
t_FWHM_0 = 20;                      % initial pulse FWHM [in ps]
P_0 = 1;                            % initial peak power [in mW]
A_0 = sqrt(P_0);                    % initial amplitude of the Gaussian
T_0 = t_FWHM_0/(2*sqrt(log(2)));    % initial pulse standard deviation
gauss = A_0*exp(-t.^2/(2*T_0^2));   % initial Gauss pulse in time
%
L_D = 200;
z_plot = [0 0.25 0.5 0.75 1.0]*L_D; % z-values to plot [in km]
gauss_F = fftshift(abs(fft(gauss)));% initial Gauss in frequency
z  = 0;                             % starting distance
n = 0;                              % controls stepping
hold on    
for z_val = z_plot                  % for selected z-values
    n = n + 1;                      % creates new step
    % P -propagator function
    P = exp(((1j/2)*beta_2*(omega.^2)+(1j/6)*beta_3*(omega.^3))*z_val);
    u_F_z = gauss_F.*P;             % propagation at point z
    u_z = ifft(u_F_z,N);            % takes inverse Fourier transform
    u_abs_z = abs(u_z).^2;
    u = fftshift(u_abs_z);          % shifts frequency components
    u_3D(:,n) = u';                 % create array for 3D plot
    plot(t,u,'LineWidth',1.5)  
end
grid on
xlabel('time [ps]','FontSize',14); ylabel('amplitude','FontSize',14);
set(gca,'FontSize',14);             % size of tick marks on both axis
pause
close all
%
% Make 3D plot
for k = 1:1:length(z_plot)          % choosing 3D plots every step
    y = z_plot(k)*ones(size(t));    % spread out along y-axis
    plot3(t,y,u_3D(:,k),'LineWidth',1.5)
    hold on
end
xlabel('time [ps]','FontSize',14); ylabel('distance [km]','FontSize',14);
set(gca,'FontSize',14);             % size of tick marks on both axis
grid on
pause
close all
