% File name: param_rate_eq_QW.m
% Purpose:
% Contains parameters for rate equation model for QW active region
% Source
% L.A. Coldren and S.W. Corzine, 
% "Diode Lasers and Photonic Integrated Circuits", Wiley 1995.
% General constants
c = 3d10;                  % velocity of light [cm/s]
q = 1.6021892d-19;         % elementary charge [C]
h_Planck = 6.626176d-34;   % Planck constant [J s]    
hbar = h_Planck/(2.0*pi);  % Dirac constant [J s]
% Geometrical dimensions
% QW active region
L = 250d-4;             % cavity length [cm];                  250 microns
w = 2d-4;               % active region width [cm];            2 microns
d = 80d-8;              % thickness of an active region [cm];  80 Angstroms 
%
%V = L*w*d;             
V = 4d-12;              % volume of active region
%
conf = 0.03;            % confinement factor [dimensionless]
V_p = V/conf;           % cavity volume [cm^3]
ref_index = 4.2;        % effective mode index
%
v_g = c/ref_index;      % group velocity [cm/s]
tau_p = 2.77d-12;       % photon life-time [s]
tau = 2.71d-9;          % carrier life-time [s]
beta_sp = 0.8d-4;       % spontaneous emission factor
%
a = 5.34d-16;           % differential gain (linear model) [cm^2]
N_tr = 1.8d18;          % carrier density at transparency [cm^-3]
eta_i = 0.8;
epsilon = 1d-17;
current_th = 1.11d-3;   % current at threshold [A]; 1.11 mA
%
% Parameters needed to determine output power
alpha_m = 45;              % mirror reflectivity [cm^-1]
lambda_ph = 1.3d-3;        % laser wavelength [microns]; 1.3 microns
freq_ph = v_g/lambda_ph;   % phonon frequency
