% File name: param_rate_eq_bulk.m
% Purpose:
% Contains parameters for rate equation model for bulk
% active region
% Source
% G.P. Agrawal and N.K. Dutta
% Long-wavelength semiconductor lasers
% Van Nostrand 1986
% Table 6.1, p. 227
%
% General constants
c = 3d10;                  % velocity of light [cm/s]
q = 1.6021892d-19;         % elementary charge [C]
h_Planck = 6.626176d-34;   % Planck constant [J s]    
hbar = h_Planck/(2.0*pi);  % Dirac constant [J s]
% Geometrical dimensions bulk active region
length = 250d-3;           % cavity length [cm]; 250 microns
width = 2d-3;              % active region width [cm]; 2 microns
thickness = 0.2d-3;        % thickness of an active region [cm]; 0.2 microns
volume_active = length*width*thickness;  % volume of active region
%
conf = 0.3;                % confinement factor [dimensionless]
V_p = volume_active/conf;  % cavity volume [cm^3]
ref_index = 3.4;           % effective mode index
%
v_g = c/ref_index;         % group velocity [cm/s]
tau_p = 1.6d-12;           % photon life-time [s]
tau = 2.2d-9;              % carrier life-time [2.71 ns]
%
a = 2.5d-16;               % differential gain (linear model) [cm^2]
% Parameters needed to determine output power
alpha_m = 45;              % mirror reflectivity [cm^-1]
lambda_ph = 1.3d-3;        % laser wavelength [microns]; 1.3 microns
freq_ph = v_g/lambda_ph;   % phonon frequency

