% File name: small_epsilon.m
% Purpose:
% Determines response function for quantum well with epsilon
clear all
param_rate_eq_QW       % input data
% 
% loop over frequency in GHz
N_max = 100;                                % number of points for plot
f_min = 0.1; f_max = 100;
freq_GHz = linspace(f_min,f_max,N_max);     % From 0.1 to 2 GHz
semilogx(freq_GHz,0);                       % make axis and force log scale
%
freq = freq_GHz*1d9;                        % convert frequency to 1/s
omega = 2*pi*freq;
power_out = 0.001;                          % output power (10 mW/facet)
%
hold on
for epsilon = [0 1.5d-17 5d-17]             % values of epsilon
% Determine steady-state photon density from a given output power
S_zero = 2*power_out/(v_g*alpha_m*h_Planck*freq_ph*V_p);
%
% Construct denominator
A = 1/tau + v_g*S_zero*a/(1+epsilon*S_zero);
B = 1/(conf*tau_p) - (1/(conf*tau_p))*S_zero*epsilon/(1+epsilon*S_zero);
C = conf*v_g*S_zero*a/(1+epsilon*S_zero);
D = (1/tau_p)*S_zero*epsilon/(1+epsilon*S_zero);
damping = A + D;
omega_R2 = A*D + C*B;

H = - omega.^2 + 1j*omega.*damping + omega_R2;
%
response = (A*D+C*B)./abs(H);
response_dB = 10*log(response);
h = plot(freq_GHz,response_dB);
end
xlabel('frequency [GHz]','FontSize',14);            % size of x label
ylabel('Response function [dB]','FontSize',14);     % size of y label
set(gca,'FontSize',14);                 % size of tick marks on both axis
axis([f_min f_max -20 20]);
text(2, 13, '\epsilon = 0','Fontsize',14)
text(2, 10, '\epsilon = 1.5 \times 10^{-17}','Fontsize',14)
text(2, 7, '\epsilon = 5 \times 10^{-17}','Fontsize',14)
pause
close all
