% File name: small_signal.m
% Purpose:
% Determines response function
clear all
param_rate_eq_bulk                      % input data
% 
% loop over frequency in GHz
N_max = 5000;                           % number of points for plot
f_min = 0.01; f_max = 100;
freq_GHz = linspace(f_min,f_max,N_max); % From 0.1 to 2 GHz
semilogx(freq_GHz,0);
%
freq = freq_GHz*1d9;                    % convert frequency to 1/s
omega = 2*pi*freq;
%
hold on
for power_out = [1d-4 1d-3 0.01 0.1 1.0]   % values of output power [W]
% Determine steady-state photon density from a given output power
S_zero = 2*power_out/(v_g*alpha_m*h_Planck*freq_ph*V_p);
%
% Construct denominator
D = - omega.^2 + 1j*omega*(1/tau +v_g*a*S_zero) + v_g*a*S_zero/tau_p;
%
response = (v_g*a*S_zero/tau_p)./abs(D);
response_dB = 10*log(response);
%
h = semilogx(freq_GHz,response_dB);
end
xlabel('frequency [GHz]','FontSize',14);            % size of x label
ylabel('Response function [dB]','FontSize',14);     % size of y label
set(gca,'FontSize',14);   % size of tick marks on both axis
axis([f_min f_max -20 35]);
text(0.05, 7, '10 \muW','Fontsize',14)
text(0.2, 18, '1 mW','Fontsize',14)
text(0.6, 27, '10 mW','Fontsize',14)
text(2.5, 33, '0.1W','Fontsize',14)
text(8, 26, '1W','Fontsize',14)
pause
close all
