% File name: gain_variable_length.m
% Computation of gain vs fiber length for fixed value of pump power
% User selects pump power which is controlled by P_p
% Calculations are repeated for P_p = 3,5,7,9 d-3 Watts
% User should also appropriately rename output file 'gain_P_3.dat'
% based on Iannone-book, p.86
% P_s  == y(1)  signal power
% P_p  == y(2)  pump power
%
clear all
gain = 0.0;
gain_temp = 0.0;
P_s = 100d-7;                            % signal power [Watts]
P_p = 9d-3;    % CHANGE                  % pump power [Watts]
%
for d_L = 0.01:0.01:10
    span = [0 d_L];
    y0 = [P_s P_p];                      % initial values of [P_s P_p]
    [z,y] = ode45('edfa_eqs',span,y0);   % z - distance
    len = length(z);
    gain_temp = y(len)/y(1);
    gain = [gain, gain_temp];
end
gain_log = log(gain);
d_L_plot = 0.01:0.01:10;
d_L_plot = [0, d_L_plot];
% plot(d_L_plot, gain_log)   % uncomment if you want to see plot when run
% axis([0 4 0 5])
% pause
% close all
%
d_u = length(d_L_plot);
fid = fopen('gain_P_9.dat', 'wt');  % CHANGE     % Open the file.
for ii = 1:d_u
fprintf (fid, ' %11.4f %11.4f\n', d_L_plot(ii),gain_log(ii)); 
end
status = fclose(fid);                    % Close the file
