% File name: gain_variable_pump.m
% Computation of gain vs power pump for fixed value of fiber length
% User selects fiber length which is controlled by d_L
% Calculations are repeated for d_L = 5,10,15 meters
% User should also appropriately rename output file 'gain_L_5.dat'
% Based on Iannone-book, p.86
% P_s  == y(1)  signal power
% P_p  == y(2)  pump power
%
clear all
gain = 0.0;
gain_temp = 0.0;
P_s = 100d-5;                            % signal power [Watts]
d_L = 5;        % CHANGE                % fiber length [meters]
span = [0 d_L];                          % region of integration [meters]
for P_p = 0.1d-3:0.1d-3:10d-3  % pump power [Watts]
    y0 = [P_s P_p];                      % initial values of [P_s P_p]
    [z,y] = ode45('edfa_eqs',span,y0);   % z - distance
    len = length(z);
    gain_temp = y(len)/y(1);
    gain = [gain, gain_temp];
end
gain_log = log(gain);
P_p_plot = 0.1:0.1:10;
P_p_plot = [0, P_p_plot];
% plot(P_p_plot, gain_log)   % uncomment if you want to see plot when run
% axis([0 10 0 30])
% pause
% close all
%
d_u = length(P_p_plot);
fid = fopen('gain_L_5.dat', 'wt');   % CHANGE   % Open the file.
for ii = 1:d_u
    fprintf (fid, ' %11.4f %11.4f\n', P_p_plot(ii),gain_log(ii)); 
end
status = fclose(fid);                    % Close the file
